# Livre de recettes

## Recettes

- Routage multi-tenant
- Travaux et tentatives en arrière-plan
- Cache + invalidation
- Politiques de limitation des tarifs
- Fichiers statiques avec ETag/compression
- Les bases de WebSocket
- Fondations de la passerelle gRPC
- Utilisation du programme d'exécution de migration

Chaque recette doit être copiée et adaptée à vos contraintes de production.